==> libreoffice-7.1.8.1.tar.xz: libreoffice-7.1.8.1/winaccessibility/source/service/ResIDGenerator.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <ResIDGenerator.hxx>

#include <cassert>

ResIDGenerator::~ResIDGenerator() {}

/**
   * SubList stores those IDs that were ever generated and deleted, the method
   * return the ID from subList first if subList is not empty,else return ++max.
   * Add the obsolete IDs by calling SetSub method
   *
   * @param
   * @return  new resource ID.
   */
long ResIDGenerator::GenerateNewResID()
{
    if (!subList.empty())
    {
        long nRes = *(subList.begin());
        subList.pop_front();
        return nRes;
    }
    assert(max < LONG_MAX);
    return -(++max);
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_25.2.6.orig.tar.xz: libreoffice-25.2.6.2/winaccessibility/source/service/ResIDGenerator.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <ResIDGenerator.hxx>

#include <cassert>

ResIDGenerator::~ResIDGenerator() {}

/**
   * SubList stores those IDs that were ever generated and deleted, the method
   * return the ID from subList first if subList is not empty, else return m_nMin--.
   * Add the obsolete IDs by calling SetSub method
   *
   * @param
   * @return  new resource ID.
   */
long ResIDGenerator::GenerateNewResID()
{
    if (!subList.empty())
    {
        long nRes = *(subList.begin());
        subList.pop_front();
        return nRes;
    }
    assert(m_nMin > LONG_MIN);
    return m_nMin--;
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
